@@ -248,3 +248,14 @@ def get_samples(dataset_id: str,
 
     response = _get_request(dst_url, params=payload)
     return response.text.splitlines()
+
+
+def get_latest_version(version, timeout=1):
+
+    dst_url = f'{SERVER_LOCATION}/pip/version'
+    payload = {'version': version}
+    try:
+        response = requests.get(dst_url, params=payload, timeout=timeout)
+        return response.json()[0]
+    except Exception:
+        return None
